/********************************************************************************
** Form generated from reading UI file 'charrunner_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHARRUNNER_CONFIG_H
#define UI_CHARRUNNER_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CharacterRunnerConfigUi
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *main;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *layout_trigger;
    QLabel *label_trigger;
    QLineEdit *edit_trigger;
    QHBoxLayout *layout_shortcut;
    QLabel *label_alias;
    QLineEdit *edit_alias;
    QLabel *label_hex;
    QLineEdit *edit_hex;
    QHBoxLayout *layout_list;
    QTreeWidget *list;
    QVBoxLayout *layout_Itemactions;
    QPushButton *addItem;
    QPushButton *deleteItem;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CharacterRunnerConfigUi)
    {
        if (CharacterRunnerConfigUi->objectName().isEmpty())
            CharacterRunnerConfigUi->setObjectName("CharacterRunnerConfigUi");
        CharacterRunnerConfigUi->resize(308, 252);
        verticalLayout = new QVBoxLayout(CharacterRunnerConfigUi);
        verticalLayout->setObjectName("verticalLayout");
        main = new QGroupBox(CharacterRunnerConfigUi);
        main->setObjectName("main");
        verticalLayout_2 = new QVBoxLayout(main);
        verticalLayout_2->setObjectName("verticalLayout_2");
        layout_trigger = new QHBoxLayout();
        layout_trigger->setObjectName("layout_trigger");
        label_trigger = new QLabel(main);
        label_trigger->setObjectName("label_trigger");

        layout_trigger->addWidget(label_trigger);

        edit_trigger = new QLineEdit(main);
        edit_trigger->setObjectName("edit_trigger");
        edit_trigger->setClearButtonEnabled(true);

        layout_trigger->addWidget(edit_trigger);


        verticalLayout_2->addLayout(layout_trigger);

        layout_shortcut = new QHBoxLayout();
        layout_shortcut->setObjectName("layout_shortcut");
        label_alias = new QLabel(main);
        label_alias->setObjectName("label_alias");

        layout_shortcut->addWidget(label_alias);

        edit_alias = new QLineEdit(main);
        edit_alias->setObjectName("edit_alias");

        layout_shortcut->addWidget(edit_alias);

        label_hex = new QLabel(main);
        label_hex->setObjectName("label_hex");

        layout_shortcut->addWidget(label_hex);

        edit_hex = new QLineEdit(main);
        edit_hex->setObjectName("edit_hex");

        layout_shortcut->addWidget(edit_hex);


        verticalLayout_2->addLayout(layout_shortcut);

        layout_list = new QHBoxLayout();
        layout_list->setObjectName("layout_list");
        list = new QTreeWidget(main);
        list->setObjectName("list");
        list->setColumnCount(2);
        list->header()->setDefaultSectionSize(75);

        layout_list->addWidget(list);

        layout_Itemactions = new QVBoxLayout();
        layout_Itemactions->setObjectName("layout_Itemactions");
        addItem = new QPushButton(main);
        addItem->setObjectName("addItem");
        addItem->setEnabled(false);

        layout_Itemactions->addWidget(addItem);

        deleteItem = new QPushButton(main);
        deleteItem->setObjectName("deleteItem");
        deleteItem->setEnabled(false);

        layout_Itemactions->addWidget(deleteItem);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layout_Itemactions->addItem(verticalSpacer_2);


        layout_list->addLayout(layout_Itemactions);


        verticalLayout_2->addLayout(layout_list);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        verticalLayout->addWidget(main);

#if QT_CONFIG(shortcut)
        label_trigger->setBuddy(edit_trigger);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CharacterRunnerConfigUi);

        QMetaObject::connectSlotsByName(CharacterRunnerConfigUi);
    } // setupUi

    void retranslateUi(QWidget *CharacterRunnerConfigUi)
    {
        main->setTitle(tr2i18n("Character Runner Config", nullptr));
        label_trigger->setText(tr2i18n("&Trigger word:", nullptr));
        label_alias->setText(tr2i18n("Alias:", nullptr));
        edit_alias->setText(QString());
        label_hex->setText(tr2i18n("Hex code:", nullptr));
        edit_hex->setText(QString());
        QTreeWidgetItem *___qtreewidgetitem = list->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Code", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Alias", nullptr));
        addItem->setText(tr2i18n("Add Item", nullptr));
        deleteItem->setText(tr2i18n("Delete Item", nullptr));
        (void)CharacterRunnerConfigUi;
    } // retranslateUi

};

namespace Ui {
    class CharacterRunnerConfigUi: public Ui_CharacterRunnerConfigUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHARRUNNER_CONFIG_H

