/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.0/applets/weather/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24TemperatureUnitListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TemperatureUnitListModel::qt_create_metaobjectdata<qt_meta_tag_ZN24TemperatureUnitListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TemperatureUnitListModel",
        "QML.Foreign",
        "AbstractUnitListModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<TemperatureUnitListModel, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TemperatureUnitListModel::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TemperatureUnitListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TemperatureUnitListModelE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24TemperatureUnitListModelE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23VisibilityUnitListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto VisibilityUnitListModel::qt_create_metaobjectdata<qt_meta_tag_ZN23VisibilityUnitListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VisibilityUnitListModel",
        "QML.Foreign",
        "AbstractUnitListModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<VisibilityUnitListModel, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VisibilityUnitListModel::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23VisibilityUnitListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23VisibilityUnitListModelE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23VisibilityUnitListModelE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21PressureUnitListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PressureUnitListModel::qt_create_metaobjectdata<qt_meta_tag_ZN21PressureUnitListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PressureUnitListModel",
        "QML.Foreign",
        "AbstractUnitListModel",
        "QML.Element",
        "QML.Singleton",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<PressureUnitListModel, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PressureUnitListModel::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PressureUnitListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PressureUnitListModelE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21PressureUnitListModelE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22WindSpeedUnitListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto WindSpeedUnitListModel::qt_create_metaobjectdata<qt_meta_tag_ZN22WindSpeedUnitListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WindSpeedUnitListModel",
        "QML.Foreign",
        "AbstractUnitListModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<WindSpeedUnitListModel, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WindSpeedUnitListModel::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WindSpeedUnitListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WindSpeedUnitListModelE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22WindSpeedUnitListModelE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN15WarningsForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto WarningsForeign::qt_create_metaobjectdata<qt_meta_tag_ZN15WarningsForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WarningsForeign",
        "QML.Element",
        "Warnings",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Enum access only",
        "QML.Foreign"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    2 },
    });
    return QtMocHelpers::metaObjectData<WarningsForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WarningsForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WarningsForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WarningsForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15WarningsForeignE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
