/****************************************************************************
** Meta object code from reading C++ file 'DiskQuota.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.0/applets/diskquota/DiskQuota.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DiskQuota.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DiskQuotaE_t {};
} // unnamed namespace

template <> constexpr inline auto DiskQuota::qt_create_metaobjectdata<qt_meta_tag_ZN9DiskQuotaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiskQuota",
        "QML.Element",
        "auto",
        "quotaInstalledChanged",
        "",
        "cleanUpToolInstalledChanged",
        "statusChanged",
        "toolTipChanged",
        "subToolTipChanged",
        "iconNameChanged",
        "updateQuota",
        "quotaProcessFinished",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "openCleanUpTool",
        "mountPoint",
        "quotaInstalled",
        "cleanUpToolInstalled",
        "status",
        "TrayStatus",
        "toolTip",
        "subToolTip",
        "iconName",
        "model",
        "QuotaListModel*",
        "ActiveStatus",
        "PassiveStatus",
        "NeedsAttentionStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'quotaInstalledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cleanUpToolInstalledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subToolTipChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateQuota'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quotaProcessFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'openCleanUpTool'
        QtMocHelpers::SlotData<void(const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'quotaInstalled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'cleanUpToolInstalled'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'status'
        QtMocHelpers::PropertyData<enum TrayStatus>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'toolTip'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'subToolTip'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'model'
        QtMocHelpers::PropertyData<QuotaListModel*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TrayStatus'
        QtMocHelpers::EnumData<enum TrayStatus>(20, 20, QMC::EnumFlags{}).add({
            {   26, TrayStatus::ActiveStatus },
            {   27, TrayStatus::PassiveStatus },
            {   28, TrayStatus::NeedsAttentionStatus },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DiskQuota, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DiskQuota::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskQuotaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskQuotaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DiskQuotaE_t>.metaTypes,
    nullptr
} };

void DiskQuota::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiskQuota *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->quotaInstalledChanged(); break;
        case 1: _t->cleanUpToolInstalledChanged(); break;
        case 2: _t->statusChanged(); break;
        case 3: _t->toolTipChanged(); break;
        case 4: _t->subToolTipChanged(); break;
        case 5: _t->iconNameChanged(); break;
        case 6: _t->updateQuota(); break;
        case 7: _t->quotaProcessFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 8: _t->openCleanUpTool((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::quotaInstalledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::cleanUpToolInstalledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::statusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::toolTipChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::subToolTipChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskQuota::*)()>(_a, &DiskQuota::iconNameChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QuotaListModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->quotaInstalled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->cleanUpToolInstalled(); break;
        case 2: *reinterpret_cast<enum TrayStatus*>(_v) = _t->status(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->toolTip(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->subToolTip(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 6: *reinterpret_cast<QuotaListModel**>(_v) = _t->model(); break;
        default: break;
        }
    }
}

const QMetaObject *DiskQuota::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiskQuota::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskQuotaE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DiskQuota::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DiskQuota::quotaInstalledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DiskQuota::cleanUpToolInstalledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DiskQuota::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DiskQuota::toolTipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DiskQuota::subToolTipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DiskQuota::iconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
