// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "noaa_debug.h"

 namespace WEATHER { namespace ION {
Q_LOGGING_CATEGORY(NOAA, "org.kde.weather.ion.noaa", QtInfoMsg)
} } 
